<?php

namespace App\Http\Controllers\Api;

use App\Http\Controllers\Controller;
use Illuminate\Http\Request;
use App\Models\UrlShortener;

use Illuminate\Support\Facades\Hash;

use App\Http\Requests\UrlShortenerRequest;

class UrlShortenerController extends Controller
{
    public function createUrl(UrlShortenerRequest $request)
    {
        // Generate a random Short URL ID
        $shortUrlId = Hash::make(rand());

        // Save the URL in the database
        UrlShortener::create([
            'url' => $request->input('url'),
            'website' => $request->input('website'),
            'short_url_id' => $shortUrlId,
        ]);

        return response()->json(['short_url_id' => $shortUrlId], 201);
    }

    /**
     * @OA\Get(
     *      path="/api/v1/fetch-url/1",
     *      operationId="fetchUrl",
     *      tags={"url"},
     *      summary="Get url by id",
     *      description="Returns the url",
     *      @OA\Response(
     *          response=200,
     *          description="Successful operation",
     *          @OA\JsonContent(ref="#/components/schemas/ProjectResource")
     *       ),
     *      @OA\Response(
     *          response=401,
     *          description="Unauthenticated",
     *      ),
     *      @OA\Response(
     *          response=403,
     *          description="Forbidden"
     *      )
     *     )
     */
    public function fetchUrl($shortUrlId)
    {
        // Retrieve the URL based on Short URL ID
        $url = UrlShortener::where('short_url_id', $shortUrlId)->first();

        if ($url) {
            return response()->json(['url' => $url->url]);
        }

        return response()->json(['error' => 'URL not found'], 404);
    }
}
